"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@ts-ioc/core");
var RequestMethod_1 = require("../RequestMethod");
/**
 * create route decorator.
 *
 * @export
 * @template T
 * @param {RequestMethod} [method]
 * @param { MetadataExtends<T>} [metaExtends]
 */
function createRouteDecorator(method, adapter, metaExtends) {
    return core_1.createMethodDecorator('Route', function (args) {
        if (adapter) {
            adapter(args);
        }
        args.next({
            isMetadata: function (arg) { return core_1.isClassMetadata(arg, ['route', 'method']); },
            match: function (arg) { return core_1.isString(arg); },
            setMetadata: function (metadata, arg) {
                metadata.route = arg;
            }
        });
        args.next({
            match: function (arg) { return core_1.isString(arg); },
            setMetadata: function (metadata, arg) {
                metadata.contentType = arg;
            }
        });
        args.next({
            match: function (arg) { return core_1.isNumber(arg); },
            setMetadata: function (metadata, arg) {
                metadata.method = arg;
            }
        });
    }, function (metadata) {
        if (metaExtends) {
            metadata = metaExtends(metadata);
        }
        metadata.method = method || RequestMethod_1.RequestMethod.Get;
        return metadata;
    });
}
exports.createRouteDecorator = createRouteDecorator;
/**
 * route decorator. define the controller method as an route.
 *
 * @Route
 */
exports.Route = createRouteDecorator();

//# sourceMappingURL=../../sourcemaps/core/decorators/Route.js.map
