"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@ts-ioc/core");
var NotFoundRoute_1 = require("./NotFoundRoute");
/**
 * base route.
 *
 * @export
 * @class BaseRoute
 * @extends {Composite}
 * @implements {IRoute}
 */
var BaseRoute = /** @class */ (function (_super) {
    tslib_1.__extends(BaseRoute, _super);
    function BaseRoute(route) {
        var _this = _super.call(this, route) || this;
        _this.url = route.substring(0);
        return _this;
    }
    BaseRoute.prototype.add = function (node) {
        var baseUrl = this.cutEmptyPath(this.url, true);
        node.url = baseUrl + node.url;
        _super.prototype.add.call(this, node);
        return this;
    };
    BaseRoute.prototype.cutEmptyPath = function (routPath, foreNull) {
        if (foreNull === void 0) { foreNull = false; }
        if (foreNull && routPath === '/') {
            return '';
        }
        if (/\/\s*$/.test(routPath)) {
            routPath = routPath.substring(0, routPath.lastIndexOf('/'));
        }
        if (/\?\S*$/.test(routPath)) {
            routPath = routPath.substring(0, routPath.lastIndexOf('?'));
        }
        return routPath;
    };
    BaseRoute.prototype.match = function (ctx) {
        var prefix = core_1.isString(ctx) ? ctx : ctx.url;
        var route = this.find(function (r) {
            return r.url && prefix && prefix.indexOf(r.url) === 0;
        }, core_1.Mode.traverseLast);
        return route;
    };
    BaseRoute.prototype.empty = function () {
        return NotFoundRoute_1.notFoundRoute;
    };
    BaseRoute.classAnnations = { "name": "BaseRoute", "params": { "constructor": ["route"], "add": ["node"], "cutEmptyPath": ["routPath", "foreNull"], "match": ["ctx"], "options": ["container", "ctx", "next"], "navigating": ["container", "ctx", "next"], "empty": [] } };
    return BaseRoute;
}(core_1.GComposite));
exports.BaseRoute = BaseRoute;

//# sourceMappingURL=../../sourcemaps/core/router/BaseRoute.js.map
